<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="de">
<context>
    <name>AbstractPluginsController</name>
    <message>
        <source>The plugin %1 is not compatible with the system.</source>
        <translation>Das Plugin %1 ist nicht mit dem System kompatibel.</translation>
    </message>
</context>
<context>
    <name>AirplaneModeApplet</name>
    <message>
        <source>Airplane Mode</source>
        <translation>Flugzeugmodus</translation>
    </message>
</context>
<context>
    <name>AirplaneModeItem</name>
    <message>
        <source>Airplane mode enabled</source>
        <translation>Flugzeugmodus aktiviert</translation>
    </message>
    <message>
        <source>Turn off</source>
        <translation>Ausschalten</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>Einschalten</translation>
    </message>
    <message>
        <source>Airplane Mode settings</source>
        <translation>Flugzeugmodus-Einstellungen</translation>
    </message>
    <message>
        <source>Airplane mode disabled</source>
        <translation>Flugzeugmodus deaktiviert</translation>
    </message>
</context>
<context>
    <name>AirplaneModePlugin</name>
    <message>
        <source>Airplane Mode</source>
        <translation>Flugzeugmodus</translation>
    </message>
</context>
<context>
    <name>AppDragWidget</name>
    <message>
        <source>Remove</source>
        <translation>Entfernen</translation>
    </message>
</context>
<context>
    <name>BluetoothApplet</name>
    <message>
        <source>Bluetooth settings</source>
        <translation>Bluetooth-Einstellungen</translation>
    </message>
</context>
<context>
    <name>BluetoothItem</name>
    <message>
        <source>Turn off</source>
        <translation>Ausschalten</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>Einschalten</translation>
    </message>
    <message>
        <source>Bluetooth settings</source>
        <translation>Bluetooth-Einstellungen</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1 verbunden</translation>
    </message>
    <message>
        <source>Connecting...</source>
        <translation>Wird verbunden ...</translation>
    </message>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation>Ausgeschaltet</translation>
    </message>
</context>
<context>
    <name>BluetoothPlugin</name>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
</context>
<context>
    <name>DBusAdaptors</name>
    <message>
        <source>Add keyboard layout</source>
        <translation>Tastaturbelegung hinzufügen</translation>
    </message>
</context>
<context>
    <name>DatetimePlugin</name>
    <message>
        <source>Datetime</source>
        <translation>Datum/Zeit</translation>
    </message>
    <message>
        <source>12-hour time</source>
        <translation>12-Stunden-Zeit</translation>
    </message>
    <message>
        <source>24-hour time</source>
        <translation>24-Stunden-Zeit</translation>
    </message>
    <message>
        <source>Time settings</source>
        <translation>Zeiteinstellungen</translation>
    </message>
</context>
<context>
    <name>DatetimeWidget</name>
    <message>
        <source>Monday</source>
        <translation>Montag</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>Dienstag</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>Mittwoch</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>Donnerstag</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>Freitag</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>Samstag</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>Sonntag</translation>
    </message>
    <message>
        <source>monday</source>
        <translation>Montag</translation>
    </message>
    <message>
        <source>tuesday</source>
        <translation>Dienstag</translation>
    </message>
    <message>
        <source>wednesday</source>
        <translation>Mittwoch</translation>
    </message>
    <message>
        <source>thursday</source>
        <translation>Donnerstag</translation>
    </message>
    <message>
        <source>friday</source>
        <translation>Freitag</translation>
    </message>
    <message>
        <source>saturday</source>
        <translation>Samstag</translation>
    </message>
    <message>
        <source>sunday</source>
        <translation>Sonntag</translation>
    </message>
    <message>
        <source>%1year%2month%3day</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>DialogManager</name>
    <message>
        <source>Are you sure you want to empty %1 items?</source>
        <translation>Sind Sie sicher, dass Sie %1 Elemente löschen möchten?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Löschen</translation>
    </message>
    <message>
        <source>This action cannot be restored</source>
        <translation>Diese Aktion kann nicht wiederhergestellt werden</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown device</source>
        <translation>Unbekanntes Gerät</translation>
    </message>
    <message>
        <source>Unknown volume</source>
        <translation>Unbekannter Datenträger</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>Festplatte</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Öffnen</translation>
    </message>
    <message>
        <source>Unmount all</source>
        <translation>Alle aushängen</translation>
    </message>
</context>
<context>
    <name>LauncherItem</name>
    <message>
        <source>Launcher</source>
        <translation>Starter</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Exit Safe Mode</source>
        <translation>Abgesicherten Modus beenden</translation>
    </message>
    <message>
        <source>Dock - Safe Mode</source>
        <translation>Dock - Abgesicherter Modus</translation>
    </message>
    <message>
        <source>The Dock is in safe mode, please exit to show it properly</source>
        <translation>Das Dock befindet sich im abgesicherten Modus, bitte beenden, um es richtig anzuzeigen</translation>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Fashion Mode</source>
        <translation>Design-Modus</translation>
    </message>
    <message>
        <source>Efficient Mode</source>
        <translation>Effizienzmodus</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>Oben</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>Unten</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Links</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Rechts</translation>
    </message>
    <message>
        <source>Keep Shown</source>
        <translation>Angezeigt lassen</translation>
    </message>
    <message>
        <source>Keep Hidden</source>
        <translation>Ausgeblendet lassen</translation>
    </message>
    <message>
        <source>Smart Hide</source>
        <translation>Intelligentes Ausblenden</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Modus</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Ort</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Status</translation>
    </message>
    <message>
        <source>Dock settings</source>
        <translation>Dock-Einstellungen</translation>
    </message>
</context>
<context>
    <name>ModuleWidget</name>
    <message>
        <source>Size</source>
        <translation>Größe</translation>
        <extra-child_page>Dock</extra-child_page>
        <extra-contents_path>/personalization/Dock</extra-contents_path>
    </message>
    <message>
        <source>Multiple Displays</source>
        <translation>Mehrfachbildschirm</translation>
        <extra-child_page>Dock</extra-child_page>
        <extra-contents_path>/personalization/Dock</extra-contents_path>
    </message>
    <message>
        <source>Plugin Area</source>
        <translation>Pluginbereich</translation>
        <extra-child_page>Dock</extra-child_page>
        <extra-contents_path>/personalization/Dock</extra-contents_path>
    </message>
    <message>
        <source>Select which icons appear in the Dock</source>
        <translation>Wählen Sie aus, welche Symbole im Dock erscheinen sollen</translation>
    </message>
    <message>
        <source>Fashion mode</source>
        <translation>Design-Modus</translation>
    </message>
    <message>
        <source>Efficient mode</source>
        <translation>Effizienzmodus</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Modus</translation>
        <extra-child_page>Dock</extra-child_page>
        <extra-contents_path>/personalization/Dock</extra-contents_path>
    </message>
    <message>
        <source>Top</source>
        <translation>Oben</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>Unten</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Links</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Rechts</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Standort</translation>
        <extra-child_page>Dock</extra-child_page>
        <extra-contents_path>/personalization/Dock</extra-contents_path>
    </message>
    <message>
        <source>Keep shown</source>
        <translation>Angezeigt lassen</translation>
    </message>
    <message>
        <source>Keep hidden</source>
        <translation>Ausgeblendet lassen</translation>
    </message>
    <message>
        <source>Smart hide</source>
        <translation>Intelligentes Ausblenden</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Status</translation>
        <extra-child_page>Dock</extra-child_page>
        <extra-contents_path>/personalization/Dock</extra-contents_path>
    </message>
    <message>
        <source>Small</source>
        <translation>Klein</translation>
    </message>
    <message>
        <source>Large</source>
        <translation>Groß</translation>
    </message>
    <message>
        <source>Show Dock</source>
        <translation>Dock anzeigen</translation>
    </message>
    <message>
        <source>On screen where the cursor is</source>
        <translation>Auf dem Bildschirm, wo sich der Zeiger befindet</translation>
    </message>
    <message>
        <source>Only on main screen</source>
        <translation>Nur auf dem Hauptbildschirm</translation>
    </message>
</context>
<context>
    <name>MultitaskingPlugin</name>
    <message>
        <source>Multitasking View</source>
        <translation>Multitasking-Ansicht</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>Abdocken</translation>
    </message>
</context>
<context>
    <name>OnboardPlugin</name>
    <message>
        <source>Onboard</source>
        <translation>Touch-Tastatur</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Einstellungen</translation>
    </message>
</context>
<context>
    <name>PowerPlugin</name>
    <message>
        <source>Power</source>
        <translation>Ausschalten / Abmelden</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Energieeinstellungen</translation>
    </message>
    <message>
        <source>Capacity %1, %2 min remaining</source>
        <translation>Kapazität %1, %2 Min. verbleibend</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr %3 min remaining</source>
        <translation>Kapazität %1, %2 Std. %3 Min. verbleibend</translation>
    </message>
    <message>
        <source>Charging %1, %2 min until full</source>
        <translation>%1 wird aufgeladen, %2 Min. bis vollständig geladen</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr %3 min until full</source>
        <translation>%1 wird aufgeladen, %2 Std. %3 Min. bis vollständig geladen</translation>
    </message>
    <message>
        <source>Capacity %1</source>
        <translation>Kapazität %1</translation>
    </message>
    <message>
        <source>Charging %1</source>
        <translation>%1 wird aufgeladen</translation>
    </message>
    <message>
        <source>Capacity %1 ...</source>
        <translation>Kapazität %1 ...</translation>
    </message>
    <message>
        <source>Capacity %1, fully charged</source>
        <translation>Kapazität %1, vollständig geladen</translation>
    </message>
</context>
<context>
    <name>SettingsModule</name>
    <message>
        <source>Dock</source>
        <translation>Dock</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Modus</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Standort</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Status</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Größe</translation>
    </message>
    <message>
        <source>Show Dock</source>
        <translation>Dock anzeigen</translation>
    </message>
    <message>
        <source>Plugin Area</source>
        <translation>Pluginbereich</translation>
    </message>
</context>
<context>
    <name>ShowDesktopPlugin</name>
    <message>
        <source>Show Desktop</source>
        <translation>Desktop anzeigen</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>Abdocken</translation>
    </message>
</context>
<context>
    <name>ShutdownPlugin</name>
    <message>
        <source>Power</source>
        <translation>Energie</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>Herunterfahren</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Bereitschaftszustand</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Ruhezustand</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Sperren</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Abmelden</translation>
    </message>
    <message>
        <source>Switch account</source>
        <translation>Konto wechseln</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Energieeinstellungen</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Neu starten</translation>
    </message>
</context>
<context>
    <name>SoundApplet</name>
    <message>
        <source>Volume</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SoundItem</name>
    <message>
        <source>Unmute</source>
        <translation>Stummschalten aufheben</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Stummschalten</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>Toneinstellungen</translation>
    </message>
    <message>
        <source>Volume %1</source>
        <translation>Lautstärke %1</translation>
    </message>
    <message>
        <source>No output devices</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SoundPlugin</name>
    <message>
        <source>Sound</source>
        <translation>Ton</translation>
    </message>
</context>
<context>
    <name>TrashPlugin</name>
    <message>
        <source>Trash</source>
        <translation>Papierkorb</translation>
    </message>
    <message>
        <source>Trash - %1 file</source>
        <translation>Papierkorb - %1 Datei</translation>
    </message>
    <message>
        <source>Trash - %1 files</source>
        <translation>Papierkorb - %1 Dateien</translation>
    </message>
    <message>
        <source>Move to Trash</source>
        <translation>In den Papierkorb verschieben</translation>
    </message>
</context>
<context>
    <name>TrashWidget</name>
    <message>
        <source>Open</source>
        <translation>Öffnen</translation>
    </message>
    <message>
        <source>Empty</source>
        <translation>Leeren</translation>
    </message>
</context>
</TS>